'use strict';
var Generator = require('yeoman-generator');
var chalk = require('chalk');
var yosay = require('yosay');

module.exports = class extends Generator {
  constructor(args, opts) {
    super(args, opts);
    console.log('App Generator', this);
    this.argument('name', {
      type: String,
      required: false,
      desc: 'The name of the app'
    });
    this.option('sass');
    this.cssSuffix = (opts.sass ? '.scss' : '.less');
    this.preprocessor = (opts.preprocessor ? '.scss' : '.less');
  }
  initializing() {
    this.log('initializing');
  }
  prompting() {
    this.log('prompting');
    this.log(yosay(
      'Welcome to the wicked ' + chalk.red('generator-preactjs') + ' generator!'
    ));
    return this.prompt([{
      type: 'input',
      name: 'name',
      message: 'Your project name',
      default: this.appname
    }, {
      type: 'input',
      name: 'preprocessor',
      message: 'Less or Sass pre-processor',
      default: 'sass'
    }]).then(answers => {
      this.log('app name', answers);
      this.props = answers;
      this.appname = answers.name || this.appname;
      return answers;
    });
  }
  writing() {
    this.fs.copy(this.templatePath('preact-boilerplate') + '/**/*', this.destinationPath(''));
    this.fs.copyTpl(
      this.templatePath('_index.html'),
      this.destinationPath('src/index.html'), {
        name: this.appname
      }
    );
    let dotfiles = [
      '.babelrc',
      '.cfignore',
      '.editorconfig',
      '.eslintignore',
      '.eslintrc',
      '.gitignore',
      '.travis.yml'
    ];
    dotfiles.forEach(file => {
      this.fs.copyTpl(this.templatePath(`preact-boilerplate/${file}`), this.destinationPath(file));
    });
    this.fs.copyTpl(this.templatePath('_README.md'), this.destinationPath('README.md'), {
      name: this.appname
    });
    this.fs.copyTpl(this.templatePath('_package.json'), this.destinationPath('package.json'), {
      name: this.appname
    });
    this.fs.copyTpl(this.templatePath('_manifest.json'), this.destinationPath('src/manifest.json'), {
      name: this.appname
    });
    this.config.set('appname', this.appname);
    this.config.set('cssSuffix', this.cssSuffix);
    this.config.save();
  }
  install() {
    this.installDependencies();
  }
};
