import { h, Component } from 'preact';
import style from './style';


class UsersFactory{
	constructor(url){
		this.url = url;
	}
	async getData(params){
		console.log('getData', params);
		const response = await fetch(this.url);
		const json = await response.json();
		return json;
	}
}

const url = '/api/my-preact-app/_all_docs?include_docs=true';
var api = new UsersFactory(url);


/**
 * Users Component - on mount fetch for data and render table.
 */
export default class Users extends Component {
	state = {
		rows: [
			{
				doc: {_id: 1, username: 'test'}
			}
		]
	};

	async componentDidMount(){
		var resp = await api.getData();
		this.setState({rows: resp.rows})
		console.log('Fetch users and populate state');
		console.warn('componentDidMount', this);
	}

	render({}, {rows = []}) {
		return (
			<div class={style.users}>
				<h1>Users</h1>
				<p>Total records {rows.length}</p>
				<table id="usersTable" class="table">
					<thead>
						<tr>
							<th>ID</th>
							<th>Username</th>
							<th>Actions</th>
						</tr>
					</thead>
					<tbody>
					{ rows.map( row => (
						<tr id={row.id}>
							<td>{row.doc._id}</td>
							<td>{row.doc.username}</td>
							<td>
								<button>Edit</button>
							</td>
						</tr>
					)) }
					</tbody>
				</table>
			</div>
		);
	}
}
